@@ -1,9 +1,9 @@
 import sys
 
-from file import File
-from formatter import format_files, get_files, get_files_rec
+from .file import File
+from .formatter import format_files, get_files, get_files_rec
 
-__version__ = "0.1"
+__version__ = "0.1.1"
 
 
 def print_help():
@@ -24,6 +24,7 @@ where :
         """
     )
 
+
 def main():
     if len(sys.argv) == 1:
         print("Error! Please, write arguments", '\n')
